@@ -9,8 +9,8 @@
 #
 package Dist::Zilla::PluginBundle::RSRCHBOY;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-# git description: 0.072-7-g802ad65
-$Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.073';
+# git description: 0.073-5-gd31da0b
+$Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.074';
 
 # ABSTRACT: Zilla your distributions like RSRCHBOY!
 
@@ -159,7 +159,8 @@ sub release_plugins {
         $self->no_install_on_release ? () : [ InstallRelease   => { install_command => 'cpanm .' } ],
         $self->no_github             ? () : [ 'GitHub::Update' => { metacpan        => 1         } ],
 
-        [ ArchiveRelease => { directory => 'releases' } ],
+        [ 'Run::AfterRelease' => { run => 'mkdir -p releases ; mv %s releases/' } ],
+
         'ConfirmRelease',
     );
 
@@ -356,7 +357,7 @@ Dist::Zilla::PluginBundle::RSRCHBOY - Zilla your distributions like RSRCHBOY!
 
 =head1 VERSION
 
-This document describes version 0.073 of Dist::Zilla::PluginBundle::RSRCHBOY - released April 01, 2017 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.074 of Dist::Zilla::PluginBundle::RSRCHBOY - released April 15, 2017 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 SYNOPSIS
 
